@@ -31,6 +31,10 @@ else:
 
 from . import linenumberarea, debugarea
 
+import sys
+if sys.version_info.major == 3:
+    unicode = str
+
 ##################
 # Constants
 ##################
@@ -471,8 +475,5 @@ class CodeEditor(QPlainTextEdit):
             cursor = self.textCursor()
             if not cursor.hasSelection():
                 return self.get_script_to_run(False)
-            script = cursor.selectedText()
-            if not script.strip():
-                return None
-            # Qt uses U+2029 for line breaks :/
-            return unicode(script).replace(u'\u2029', '\n')
+            script = cursor.selection().toPlainText().strip()
+            return script
