@@ -19,6 +19,16 @@ from kabaret.app.ui.gui.widgets.flow.navigation_control import (
 from .pythoneditor import CodeEditor
 from . import syntax, syntaxstyles
 
+def register_pyscript_editor():
+    from ..pyscript_editor import PyScriptEditor
+    from kabaret.app.ui.gui.widgets.editors import editor_factory
+    factory = editor_factory()
+    if PyScriptEditor not in factory._editor_types:
+        factory.register_editor_type(PyScriptEditor)
+
+# Autmatically register our nice pyscript editor:
+register_pyscript_editor()
+
 
 class ScriptEditor(QtWidgets.QTextEdit):
 
@@ -84,6 +94,8 @@ class OutPutTextEdit(QtWidgets.QPlainTextEdit):
         'CTRL+Enter without selection to run the whole script.\n'
         '\n'
         'CTRL+Backspace to clear output\n'
+        'CTRL+Wheel to Zoom In/Out in a text area\n'
+        'CTRL++ / CTRL+- to Zoom In/Out both text area\n'
     )
 
     def __init__(self, view, parent=None):
@@ -148,7 +160,8 @@ class ScriptView(DockedView):
         self._start_oid = oid
         super(ScriptView, self).__init__(session, view_id, hidden=hidden, area=area)
         self._globals_dict = {"__name__": "__kabaret_script_view__"}
-
+        self._clear_output()
+        
     def receive_event(self, event, data):
         # This view does not react to events.
         if self._show_events and self.output is not None:
@@ -164,6 +177,19 @@ class ScriptView(DockedView):
         self.add_header_tool('*', '*', 'Duplicate View', self.create_view)
 
         # ---- View Menu Actions
+        a = self.view_menu.addAction('Font Size +', self._font_size_incr)
+        a.setShortcut(
+            QtGui.QKeySequence(
+                QtCore.Qt.CTRL + QtCore.Qt.Key_Plus
+            )
+        )
+        a = self.view_menu.addAction('Font Size -', self._font_size_decr)
+        a.setShortcut(
+            QtGui.QKeySequence(
+                QtCore.Qt.CTRL + QtCore.Qt.Key_Minus
+            )
+        )
+
         a = self.view_menu.addAction('Clear Output', self._clear_output)
         a.setShortcut(
             QtGui.QKeySequence(
@@ -223,6 +249,14 @@ class ScriptView(DockedView):
 
         parent.layout().addWidget(self.splitter)
 
+    def _font_size_incr(self):
+        self.editor.zoomIn()
+        self.output.zoomIn()
+
+    def _font_size_decr(self):
+        self.editor.zoomOut()
+        self.output.zoomOut()
+
     def _toggle_event_logging(self):
         self._show_events = not self._show_events
         self._toggle_events_action.setChecked(self._show_events)
